"use strict";

exports.__esModule = true;
exports.PeersGraph = PeersGraph;
var _react = _interopRequireWildcard(require("react"));
var _material = require("@mui/material");
var _ScopedCssBaseline = _interopRequireDefault(require("@mui/material/ScopedCssBaseline"));
var _PeerContext = require("../context/PeerContext");
var _constants = require("../constants");
var _GraphWithTooltip = _interopRequireDefault(require("./GraphWithTooltip"));
var _throttledCallback = require("../hooks/throttledCallback");
var _utils = require("../utils");
var _excluded = ["refreshInterval"];
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
function PeersGraph(_ref) {
  var _ref$refreshInterval = _ref.refreshInterval,
    refreshInterval = _ref$refreshInterval === void 0 ? _constants.DEFAULT_REFRESH_INTERVAL : _ref$refreshInterval,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  var peer = (0, _react.useContext)(_PeerContext.PeerContext);
  var _useState = (0, _react.useState)([]),
    connections = _useState[0],
    setConnections = _useState[1];

  // Callback to update connections state only on some change
  var updateConnections = (0, _react.useCallback)(function () {
    if (!peer || !peer.node) {
      return;
    }
    var newConnections = peer.getPeerConnectionsInfo();
    setConnections(function (prevConnections) {
      // Compare and check if connections changed
      if (JSON.stringify(prevConnections) === JSON.stringify(newConnections)) {
        // Return previous connections to prevent re-render
        return prevConnections;
      }
      return newConnections;
    });
  }, [peer]);
  var throttledUpdateConnections = (0, _throttledCallback.useThrottledCallback)(updateConnections, _constants.THROTTLE_WAIT_TIME, {
    leading: false
  });
  (0, _react.useEffect)(function () {
    if (!peer || !peer.node) {
      return;
    }
    peer.node.addEventListener('peer:connect', throttledUpdateConnections);
    peer.node.addEventListener('peer:disconnect', throttledUpdateConnections);
    return function () {
      var _peer$node, _peer$node2;
      (_peer$node = peer.node) === null || _peer$node === void 0 ? void 0 : _peer$node.removeEventListener('peer:connect', throttledUpdateConnections);
      (_peer$node2 = peer.node) === null || _peer$node2 === void 0 ? void 0 : _peer$node2.removeEventListener('peer:disconnect', throttledUpdateConnections);
    };
  }, [peer, throttledUpdateConnections]);
  (0, _react.useEffect)(function () {
    // TODO: Add event for connection close and remove refresh in interval
    var intervalID = setInterval(throttledUpdateConnections, refreshInterval);

    // Update connections immediately on first render
    throttledUpdateConnections();
    return function () {
      clearInterval(intervalID);
    };
  }, [throttledUpdateConnections]);
  var data = (0, _react.useMemo)(function () {
    if (!peer) {
      return {
        nodes: [],
        links: []
      };
    }
    var debugInfo = {
      selfInfo: peer.getPeerSelfInfo(),
      connInfo: connections
    };
    var _updateGraphDataWithD = (0, _utils.updateGraphDataWithDebugInfo)(peer, debugInfo),
      nodesMap = _updateGraphDataWithD.nodesMap,
      linksMap = _updateGraphDataWithD.linksMap;
    return {
      nodes: Array.from(nodesMap.values()),
      links: Array.from(linksMap.values())
    };
  }, [peer, connections]);
  return /*#__PURE__*/_react["default"].createElement(_ScopedCssBaseline["default"], null, /*#__PURE__*/_react["default"].createElement(_material.Box, _extends({
    mt: 1
  }, props), /*#__PURE__*/_react["default"].createElement(_GraphWithTooltip["default"], {
    data: data
  })));
}