"use strict";

exports.__esModule = true;
exports.SelfInfo = SelfInfo;
var _react = _interopRequireWildcard(require("react"));
var _peer = require("@cerc-io/peer");
var _material = require("@mui/material");
var _PeerContext = require("../context/PeerContext");
var _constants = require("../constants");
var _throttledCallback = require("../hooks/throttledCallback");
var _excluded = ["relayNodes", "refreshInterval"];
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
var STYLES = {
  selfInfoHead: {
    marginBottom: 1 / 2
  },
  primaryRelaySelect: {
    marginRight: 1,
    minWidth: 200
  },
  nodeStartedTableCell: {
    width: 150
  }
};
function SelfInfo(_ref) {
  var _localStorage$getItem, _localStorage$getItem2;
  var relayNodes = _ref.relayNodes,
    _ref$refreshInterval = _ref.refreshInterval,
    refreshInterval = _ref$refreshInterval === void 0 ? _constants.DEFAULT_REFRESH_INTERVAL : _ref$refreshInterval,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  var peer = (0, _react.useContext)(_PeerContext.PeerContext);
  var _useState = (0, _react.useState)(),
    selfInfo = _useState[0],
    setSelfInfo = _useState[1];
  var _useState2 = (0, _react.useState)((_localStorage$getItem = localStorage.getItem('primaryRelay')) !== null && _localStorage$getItem !== void 0 ? _localStorage$getItem : ''),
    primaryRelay = _useState2[0],
    setPrimaryRelay = _useState2[1];
  var updateInfo = (0, _react.useCallback)(function () {
    setSelfInfo(peer.getPeerSelfInfo());
  }, [peer]);
  var throttledUpdateInfo = (0, _throttledCallback.useThrottledCallback)(updateInfo, _constants.THROTTLE_WAIT_TIME);
  var handlePrimaryRelayChange = (0, _react.useCallback)(function () {
    // Set selected primary relay in localStorage and refresh app
    localStorage.setItem('primaryRelay', primaryRelay);
    window.location.reload(false);
  }, [primaryRelay]);
  (0, _react.useEffect)(function () {
    if (!peer || !peer.node) {
      return;
    }
    peer.node.peerStore.addEventListener('change:multiaddrs', throttledUpdateInfo);
    throttledUpdateInfo();
    return function () {
      var _peer$node;
      (_peer$node = peer.node) === null || _peer$node === void 0 ? void 0 : _peer$node.peerStore.removeEventListener('change:multiaddrs', throttledUpdateInfo);
    };
  }, [peer, throttledUpdateInfo]);
  return /*#__PURE__*/_react["default"].createElement(_material.Box, props, /*#__PURE__*/_react["default"].createElement(_material.Grid, {
    container: true,
    sx: STYLES.selfInfoHead
  }, /*#__PURE__*/_react["default"].createElement(_material.Grid, {
    item: true,
    xs: "auto"
  }, /*#__PURE__*/_react["default"].createElement(_material.Typography, {
    variant: "subtitle2",
    color: "inherit",
    noWrap: true
  }, /*#__PURE__*/_react["default"].createElement("b", null, "Self Node Info"))), /*#__PURE__*/_react["default"].createElement(_material.Grid, {
    item: true,
    xs: true
  }), /*#__PURE__*/_react["default"].createElement(_material.Grid, {
    item: true,
    xs: "auto"
  }, /*#__PURE__*/_react["default"].createElement(_material.Box, {
    display: "flex",
    alignItems: "flex-end"
  }, /*#__PURE__*/_react["default"].createElement(_material.FormControl, {
    variant: "standard",
    sx: STYLES.primaryRelaySelect,
    size: "small"
  }, /*#__PURE__*/_react["default"].createElement(_material.InputLabel, {
    shrink: true,
    id: "primary-relay-label"
  }, "Primary Relay"), /*#__PURE__*/_react["default"].createElement(_material.Select, {
    displayEmpty: true,
    labelId: "primary-relay-label",
    id: "primary-label",
    value: primaryRelay,
    label: "Primary Relay",
    onChange: function onChange(event) {
      return setPrimaryRelay(event.target.value);
    }
  }, /*#__PURE__*/_react["default"].createElement(_material.MenuItem, {
    value: ""
  }, "<random>"), relayNodes.map(function (relayNode) {
    return /*#__PURE__*/_react["default"].createElement(_material.MenuItem, {
      value: relayNode,
      key: relayNode
    }, relayNode.split('/')[2]);
  }))), /*#__PURE__*/_react["default"].createElement(_material.Button, {
    variant: "contained",
    size: "small",
    disabled: primaryRelay === ((_localStorage$getItem2 = localStorage.getItem('primaryRelay')) !== null && _localStorage$getItem2 !== void 0 ? _localStorage$getItem2 : ''),
    onClick: handlePrimaryRelayChange,
    sx: STYLES.primaryRelayButton
  }, "UPDATE")))), /*#__PURE__*/_react["default"].createElement(_material.TableContainer, {
    component: _material.Paper
  }, /*#__PURE__*/_react["default"].createElement(_material.Table, {
    size: "small"
  }, /*#__PURE__*/_react["default"].createElement(_material.TableBody, null, /*#__PURE__*/_react["default"].createElement(_material.TableRow, null, /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
    size: "small"
  }, /*#__PURE__*/_react["default"].createElement("b", null, "Peer ID")), /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
    size: "small"
  }, selfInfo && selfInfo.peerId + " ( " + (0, _peer.getPseudonymForPeerId)(selfInfo.peerId) + " )"), /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
    size: "small",
    align: "right"
  }, /*#__PURE__*/_react["default"].createElement("b", null, "Node started")), /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
    size: "small",
    sx: STYLES.nodeStartedTableCell
  }, peer && peer.node && peer.node.isStarted().toString())), /*#__PURE__*/_react["default"].createElement(_material.TableRow, null, /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
    size: "small"
  }, /*#__PURE__*/_react["default"].createElement("b", null, "Relay node")), /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
    size: "small",
    colSpan: 3
  }, selfInfo && selfInfo.primaryRelayMultiaddr + " ( " + (0, _peer.getPseudonymForPeerId)(selfInfo.primaryRelayPeerId) + " )")), /*#__PURE__*/_react["default"].createElement(_material.TableRow, null, /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
    size: "small"
  }, /*#__PURE__*/_react["default"].createElement("b", null, "Multiaddrs")), /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
    size: "small",
    colSpan: 3
  }, /*#__PURE__*/_react["default"].createElement(_material.TableContainer, null, /*#__PURE__*/_react["default"].createElement(_material.Table, {
    size: "small"
  }, /*#__PURE__*/_react["default"].createElement(_material.TableBody, null, selfInfo && selfInfo.multiaddrs.map(function (multiaddr) {
    return /*#__PURE__*/_react["default"].createElement(_material.TableRow, {
      key: multiaddr
    }, /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
      size: "small"
    }, multiaddr));
  }))))))))));
}