"use strict";

exports.__esModule = true;
exports.updateGraphDataWithDebugInfo = void 0;
var _peer = require("@cerc-io/peer");
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
var GRAPH_NODE_COLOR = {
  blue: 0,
  green: 2,
  red: 3,
  yellow: 8
};

/**
 * Method to create/update graph data with debugInfo
 * @param selfPeer
 * @param debugInfo
 * @param nodesMap
 * @param linksMap
 */
var updateGraphDataWithDebugInfo = function updateGraphDataWithDebugInfo(selfPeer, debugInfo, nodesMap, linksMap) {
  if (nodesMap === void 0) {
    nodesMap = new Map();
  }
  if (linksMap === void 0) {
    linksMap = new Map();
  }
  var selfInfo = debugInfo.selfInfo,
    connInfo = debugInfo.connInfo;

  // Update from selfInfo
  nodesMap.set(selfInfo.peerId, _extends({
    // Set node color to blue and label to Peer by default
    colorIndex: GRAPH_NODE_COLOR.blue,
    label: 'Peer'
  }, nodesMap.get(selfInfo.peerId), {
    id: selfInfo.peerId,
    pseudonym: (0, _peer.getPseudonymForPeerId)(selfInfo.peerId),
    // Override multiaddrs from selfInfo
    multiaddrs: selfInfo.multiaddrs
  }, selfPeer.peerId.toString() === selfInfo.peerId && {
    size: 14,
    colorIndex: GRAPH_NODE_COLOR.red,
    label: 'Self'
  }));

  // Update nodes from connections info
  connInfo.forEach(function (conn) {
    nodesMap.set(conn.peerId, _extends({
      // Set node color to blue and label to Peer by default
      colorIndex: GRAPH_NODE_COLOR.blue,
      label: 'Peer',
      // Set connection multiaddr if node already does not exist
      // Self info will update with actual multiaddr
      multiaddrs: [conn.multiaddr]
    }, nodesMap.get(conn.peerId), conn.isPeerRelay && {
      colorIndex: GRAPH_NODE_COLOR.yellow,
      label: 'Relay (secondary)'
    }, {
      id: conn.peerId,
      pseudonym: (0, _peer.getPseudonymForPeerId)(conn.peerId)
    }, conn.multiaddr === selfPeer.relayNodeMultiaddr.toString() && {
      colorIndex: GRAPH_NODE_COLOR.green,
      label: 'Relay (primary)'
    }));
  });

  // Update links from connections info
  connInfo.forEach(function (conn) {
    var source = selfInfo.peerId;

    // Change source node for link to relay incase of relayed connection
    // Check if relay node exists in graph
    if (conn.type === 'relayed' && nodesMap.has(conn.hopRelayPeerId)) {
      source = conn.hopRelayPeerId;
    }

    // Form unique links between peers by concatenating ids based on comparison
    var linkId = source < conn.peerId ? source + "-" + conn.peerId : conn.peerId + "-" + source;
    linksMap.set(linkId, {
      id: linkId,
      source: source,
      target: conn.peerId
    });
  });
  return {
    nodesMap: nodesMap,
    linksMap: linksMap
  };
};
exports.updateGraphDataWithDebugInfo = updateGraphDataWithDebugInfo;